@@ -14,6 +14,7 @@ from velbus.messages.bus_off import BusOffMessage
 from velbus.module_registry import ModuleRegistry
 from velbus.messages.receive_buffer_full import ReceiveBufferFullMessage
 from velbus.messages.module_type import ModuleTypeMessage
+from velbus.messages.module_subtype import ModuleSubTypeMessage
 from velbus.messages.set_realtime_clock import SetRealtimeClock
 from velbus.messages.set_daylight_saving import SetDaylightSaving
 from velbus.messages.set_date import SetDate
@@ -97,6 +98,9 @@ class Controller(object):
 
             def module_loaded():
                 self._nb_of_modules_loaded += 1
+                self.logger.debug("Loaded modules "
+                                  + str(self._nb_of_modules_loaded)
+                                  + " of " + str(len(self._modules)))
                 if self._nb_of_modules_loaded >= len(self._modules):
                     callback()
             for module in self._modules:
@@ -131,18 +135,56 @@ class Controller(object):
         if isinstance(message, ReceiveBufferFullMessage):
             self.logger.error("Velbus receive buffer full message received")
         if isinstance(message, ModuleTypeMessage):
-            self.logger.debug("Module type response received")
+            self.logger.debug("Module type response received from address "
+                              + str(message.address))
             name = message.module_name()
             address = message.address
             m_type = message.module_type
             if name == "Unknown":
-                self.logger.warning("Unknown module (code: " + str(message.module_type) + ')')
+                self.logger.warning("Unknown module (code: "
+                                    + str(message.module_type) + ')')
                 return
             if name in ModuleRegistry:
                 module = ModuleRegistry[name](m_type, name, address, self)
                 self._modules[address] = module
             else:
-                self.logger.warning("Module " + name + " is not yet supported.")
+                self.logger.warning("Module " + name + " is not yet supported")
+        if isinstance(message, ModuleSubTypeMessage):
+            self.logger.debug("Module subtype response received from address "
+                              + str(message.address))
+            name = message.module_name()
+            address = message.address
+            m_type = message.module_type
+            if name == "Unknown":
+                self.logger.warning("Unknown module (code: "
+                                    + str(message.module_type) + ')')
+                return
+            if "SUB_" + name in ModuleRegistry:
+                subname = "SUB_" + name
+                if message.sub_address_1 != 0xff:
+                    module = ModuleRegistry[subname](m_type, subname,
+                                                     message.sub_address_1,
+                                                     address, 1, self)
+                    self._modules[message.sub_address_1] = module
+                if message.sub_address_2 != 0xff:
+                    module = ModuleRegistry[subname](m_type, subname,
+                                                     message.sub_address_2,
+                                                     address, 2, self)
+                    self._modules[message.sub_address_2] = module
+                if message.sub_address_3 != 0xff:
+                    module = ModuleRegistry[subname](m_type, subname,
+                                                     message.sub_address_3,
+                                                     address, 3, self)
+                    self._modules[message.sub_address_3] = module
+                if message.sub_address_4 != 0xff and name != "VMBGPOD" \
+                    and name != "VMBGPO":
+                    module = ModuleRegistry[subname](m_type, subname,
+                                                     message.sub_address_4,
+                                                     address, 4, self)
+                    self._modules[message.sub_address_4] = module
+            else:
+                self.logger.warning("Module " + name
+                                    + " does not yet support sub modules")
         for subscriber in self.__subscribers:
             subscriber(message)
 
@@ -154,7 +196,7 @@ class Controller(object):
 
     def sync_clock(self):
         """
-        This will send all the needed messages to sync the cloc
+        This will send all the needed messages to sync the clock
         """
         self.send(SetRealtimeClock())
         self.send(SetDate())
