@@ -92,7 +92,7 @@ register_command(COMMAND_CODE, ChannelNamePart3Message)
 register_command(COMMAND_CODE, ChannelNamePart3Message2, 'VMBGP1')
 register_command(COMMAND_CODE, ChannelNamePart3Message2, 'VMBGP2')
 register_command(COMMAND_CODE, ChannelNamePart3Message2, 'VMBGP4')
-register_command(COMMAND_CODE, ChannelNamePart3Message2, 'VMBGP0')
+register_command(COMMAND_CODE, ChannelNamePart3Message2, 'VMBGPO')
 register_command(COMMAND_CODE, ChannelNamePart3Message2, 'VMBGPOD')
 register_command(COMMAND_CODE, ChannelNamePart3Message2, 'VMBGP4PIR')
 register_command(COMMAND_CODE, ChannelNamePart3Message3, 'VMB1BL')
