@@ -10,3 +10,5 @@ from velbus.modules.vmb1ts import VMB1TSModule
 from velbus.modules.vmbiro import VMBIROModule
 from velbus.modules.vmbbl import VMB1BLModule, VMB2BLModule, VMB1BLEModule, VMB2BLEModule
 from velbus.modules.vmbmeteo import VMBMETEOModule
+from velbus.modules.vmbdme import VMBDMEModule
+from velbus.modules.vmb4dc import VMB4DCModule
