@@ -24,7 +24,7 @@ class VMBMETEOModule(Module):
     def getMinTemp(self):
         return self._min
 
-    def getMiaxTemp(self):
+    def getMaxTemp(self):
         return self._max
 
     def getCurTemp(self):
